@@ -11,6 +11,7 @@
 #include "interface.hpp"
 
 #include <memory>
+#include <string_view>
 
 namespace orcus {
 
@@ -28,7 +29,7 @@ public:
     orcus_gnumeric(spreadsheet::iface::import_factory* factory);
     ~orcus_gnumeric();
 
-    static bool detect(const unsigned char* blob, size_t size);
+    static bool detect(std::string_view strm);
 
     virtual void read_file(std::string_view filepath) override;
     virtual void read_file(std::u16string_view filepath) override;
